@@ -3,19 +3,22 @@ from ufo2ft.featureWriters import ast
 
 
 class FeatureWriterTest:
-
     # subclasses must override this
     FeatureWriter = None
 
     @classmethod
-    def writeFeatures(cls, ufo, **kwargs):
+    def writeFeatures(cls, ufo, compiler=None, **kwargs):
         """Return a new FeatureFile object containing only the newly
         generated statements, or None if no new feature was generated.
         """
         writer = cls.FeatureWriter(**kwargs)
         feaFile = parseLayoutFeatures(ufo)
-        n = len(feaFile.statements)
-        if writer.write(ufo, feaFile):
+        old_statements = [st.asFea() for st in feaFile.statements]
+
+        if writer.write(ufo, feaFile, compiler=compiler):
             new = ast.FeatureFile()
-            new.statements = feaFile.statements[n:]
+
+            for statement in feaFile.statements:
+                if statement.asFea() not in old_statements:
+                    new.statements.append(statement)
             return new
