@@ -5,7 +5,7 @@ from textwrap import dedent
 
 import pytest
 
-from ufo2ft.constants import OBJECT_LIBS_KEY
+from ufo2ft.constants import ANCHOR_LIB_GPOS_CONTEXT_KEY, OBJECT_LIBS_KEY
 from ufo2ft.featureCompiler import FeatureCompiler, parseLayoutFeatures
 from ufo2ft.featureWriters import ast
 from ufo2ft.featureWriters.markFeatureWriter import (
@@ -933,6 +933,97 @@ class MarkFeatureWriterTest(FeatureWriterTest):
 
         assert str(generated) == expected
 
+    def test_contextual_abvm_blwm_anchors(self, FontClass):
+        ufo = FontClass()
+        ufo.info.unitsPerEm = 1000
+
+        iMark = ufo.newGlyph("iMark-khmer")
+        iMark.unicode = 0x17B7
+        iMark.appendAnchor({"name": "_topright", "x": 412, "y": 600})
+
+        iiMark = ufo.newGlyph("iiMark-khmer")
+        iiMark.unicode = 0x17B8
+        iiMark.appendAnchor({"name": "_topright", "x": 412, "y": 600})
+
+        kaBelow = ufo.newGlyph("ka-khmer.below")
+        kaBelow.appendAnchor({"name": "_bottom", "x": 276, "y": 0})
+
+        ka = ufo.newGlyph("ka-khmer")
+        ka.unicode = 0x1780
+        ka.appendAnchor({"name": "topright", "x": 470, "y": 600})
+        ka.appendAnchor(
+            {"name": "*topright", "x": 276, "y": 700, "identifier": "*topright"}
+        )
+        ka.appendAnchor({"name": "bottom", "x": 276, "y": 0})
+        ka.appendAnchor(
+            {"name": "*bottom", "x": 276, "y": 100, "identifier": "*bottom"}
+        )
+
+        ka.lib[OBJECT_LIBS_KEY] = {
+            "*topright": {
+                "GPOS_Context": "lookupflag UseMarkFilteringSet [iMark-khmer]; "
+                "* ka-khmer iMark-khmer"
+            },
+            "*bottom": {
+                "GPOS_Context": "lookupflag UseMarkFilteringSet [ka-khmer.below]; *"
+            },
+        }
+
+        writer = MarkFeatureWriter()
+        feaFile = ast.FeatureFile()
+        assert str(feaFile) == ""
+        assert writer.write(ufo, feaFile)
+
+        assert str(feaFile) == dedent(
+            """\
+            markClass ka-khmer.below <anchor 276 0> @MC_bottom;
+            markClass iMark-khmer <anchor 412 600> @MC_topright;
+            markClass iiMark-khmer <anchor 412 600> @MC_topright;
+
+            lookup abvm_mark2base {
+                pos base ka-khmer
+                    <anchor 470 600> mark @MC_topright;
+            } abvm_mark2base;
+
+            lookup ContextualAbvm_0 {
+                pos base ka-khmer
+                    <anchor 276 700> mark @MC_topright;
+            } ContextualAbvm_0;
+
+            lookup ContextualAbvmDispatch_0 {
+                lookupflag UseMarkFilteringSet [iMark-khmer];
+                # * ka-khmer iMark-khmer
+                pos [ka-khmer] @MC_topright' lookup ContextualAbvm_0 ka-khmer iMark-khmer;
+            } ContextualAbvmDispatch_0;
+
+            lookup blwm_mark2base {
+                pos base ka-khmer
+                    <anchor 276 0> mark @MC_bottom;
+            } blwm_mark2base;
+
+            lookup ContextualBlwm_0 {
+                pos base ka-khmer
+                    <anchor 276 100> mark @MC_bottom;
+            } ContextualBlwm_0;
+
+            lookup ContextualBlwmDispatch_0 {
+                lookupflag UseMarkFilteringSet [ka-khmer.below];
+                # *
+                pos [ka-khmer] @MC_bottom' lookup ContextualBlwm_0;
+            } ContextualBlwmDispatch_0;
+
+            feature abvm {
+                lookup abvm_mark2base;
+                lookup ContextualAbvmDispatch_0;
+            } abvm;
+
+            feature blwm {
+                lookup blwm_mark2base;
+                lookup ContextualBlwmDispatch_0;
+            } blwm;
+            """
+        )
+
     def test_shared_script_char(self, FontClass):
         ufo = FontClass()
         ufo.info.unitsPerEm = 1000
@@ -1685,12 +1776,6 @@ class MarkFeatureWriterTest(FeatureWriterTest):
 
         generated = self.writeFeatures(ufo, groupMarkClasses=groupMarkClasses)
 
-        assert (
-            "The base glyph a and mark glyph acutecomb are ambiguously "
-            f"connected by several anchor classes: {warning}. "
-            "The last one will prevail." in caplog.text
-        )
-
         assert str(generated) == expected
 
     def test_skipExportGlyphs(self, testufo):
@@ -1788,9 +1873,9 @@ class MarkFeatureWriterTest(FeatureWriterTest):
         lookup = feature.statements[-3].lookup
         assert str(lookup) == (
             "lookup ContextualMarkDispatch_0 {\n"
-            "    lookupflag UseMarrkFilteringSet [twodotshorizontalbelow];\n"
-            "    # reh-ar * behDotess-ar.medi &\n"
-            "    pos reh-ar [behDotless-ar.init] behDotess-ar.medi"
+            "    lookupflag UseMarkFilteringSet [twodotshorizontalbelow-ar];\n"
+            "    # reh-ar * behDotless-ar.medi &\n"
+            "    pos reh-ar [behDotless-ar.init] behDotless-ar.medi"
             " @MC_bottom'"
             " lookup ContextualMark_0;\n"
             "} ContextualMarkDispatch_0;\n"
@@ -1799,11 +1884,15 @@ class MarkFeatureWriterTest(FeatureWriterTest):
         lookup = feature.statements[-2].lookup
         assert str(lookup) == (
             "lookup ContextualMarkDispatch_1 {\n"
-            "    lookupflag UseMarrkFilteringSet [twodotsverticalbelow];\n"
+            "    lookupflag UseMarkFilteringSet [twodotsverticalbelow-ar];\n"
+            "    # dotbelow-ar *\n"
+            "    pos dotbelow-ar [behDotless-ar.init.alt]"
+            " @MC_bottom'"
+            " lookup ContextualMark_1;\n"
             "    # reh-ar *\n"
             "    pos reh-ar [behDotless-ar.init behDotless-ar.init.alt]"
             " @MC_bottom'"
-            " lookup ContextualMark_1;\n"
+            " lookup ContextualMark_2;\n"
             "} ContextualMarkDispatch_1;\n"
         )
 
@@ -1813,7 +1902,7 @@ class MarkFeatureWriterTest(FeatureWriterTest):
             "    # reh-ar *\n"
             "    pos reh-ar [behDotless-ar.init]"
             " @MC_bottom'"
-            " lookup ContextualMark_2;\n"
+            " lookup ContextualMark_3;\n"
             "} ContextualMarkDispatch_2;\n"
         )
 
@@ -2011,10 +2100,146 @@ class MarkFeatureWriterTest(FeatureWriterTest):
             """
         )
 
+    def test_contextual_liga_anchor_no_number(self, testufo):
+        fi = testufo["f_i"]
+        fi.appendAnchor(
+            {"name": "*top.tilde", "x": 300, "y": 500, "identifier": "*top.tilde"}
+        )
+        fi.appendAnchor(
+            {"name": "*top_1.acute", "x": 200, "y": 300, "identifier": "*top_1.acute"}
+        )
+        fi.lib[OBJECT_LIBS_KEY] = {
+            "*top.tilde": {
+                "GPOS_Context": "* tildecomb",
+            },
+            "*top_1.acute": {
+                "GPOS_Context": "* acutecomb",
+            },
+        }
+
+        writer = MarkFeatureWriter()
+        feaFile = ast.FeatureFile()
+        assert writer.write(testufo, feaFile)
+
+        assert str(feaFile) == dedent(
+            """\
+            markClass acutecomb <anchor 100 200> @MC_top;
+            markClass tildecomb <anchor 100 200> @MC_top;
+
+            lookup mark2base {
+                pos base a
+                    <anchor 100 200> mark @MC_top;
+            } mark2base;
+
+            lookup mark2liga {
+                pos ligature f_i
+                        <anchor 100 500> mark @MC_top
+                    ligComponent
+                        <anchor 600 500> mark @MC_top;
+            } mark2liga;
+
+            lookup ContextualMark_0 {
+                pos base f_i
+                    <anchor 300 500> mark @MC_top;
+            } ContextualMark_0;
+
+            lookup ContextualMark_1 {
+                pos ligature f_i
+                        <anchor 200 300> mark @MC_top
+                    ligComponent
+                        <anchor NULL>;
+            } ContextualMark_1;
+
+            lookup ContextualMarkDispatch_0 {
+                # * tildecomb
+                pos [f_i] @MC_top' lookup ContextualMark_0 tildecomb;
+                # * acutecomb
+                pos [f_i] @MC_top' lookup ContextualMark_1 acutecomb;
+            } ContextualMarkDispatch_0;
+
+            feature mark {
+                lookup mark2base;
+                lookup mark2liga;
+                lookup ContextualMarkDispatch_0;
+            } mark;
+
+            feature mkmk {
+                lookup mark2mark_top {
+                    @MFS_mark2mark_top = [acutecomb tildecomb];
+                    lookupflag UseMarkFilteringSet @MFS_mark2mark_top;
+                    pos mark tildecomb
+                        <anchor 100 300> mark @MC_top;
+                } mark2mark_top;
+
+            } mkmk;
+            """
+        )
+
+    def test_contextual_mkmk_anchors(self, testufo):
+        tildecomb = testufo["tildecomb"]
+
+        tildecomb.appendAnchor(
+            {"name": "*top", "x": 120, "y": 400, "identifier": "*top"}
+        )
+        tildecomb.lib[OBJECT_LIBS_KEY] = {
+            "*top": {
+                "GPOS_Context": "f *",
+            },
+        }
+
+        writer = MarkFeatureWriter()
+        feaFile = ast.FeatureFile()
+        assert str(feaFile) == ""
+        assert writer.write(testufo, feaFile)
+
+        assert str(feaFile) == dedent(
+            """\
+            markClass acutecomb <anchor 100 200> @MC_top;
+            markClass tildecomb <anchor 100 200> @MC_top;
+
+            lookup mark2mark_top {
+                @MFS_mark2mark_top = [acutecomb tildecomb];
+                lookupflag UseMarkFilteringSet @MFS_mark2mark_top;
+                pos mark tildecomb
+                    <anchor 100 300> mark @MC_top;
+            } mark2mark_top;
+
+            lookup ContextualMarkToMark_0 {
+                pos mark tildecomb
+                    <anchor 120 400> mark @MC_top;
+            } ContextualMarkToMark_0;
+
+            lookup ContextualMarkToMarkDispatch_0 {
+                # f *
+                pos f [tildecomb] @MC_top' lookup ContextualMarkToMark_0;
+            } ContextualMarkToMarkDispatch_0;
+
+            feature mark {
+                lookup mark2base {
+                    pos base a
+                        <anchor 100 200> mark @MC_top;
+                } mark2base;
+
+                lookup mark2liga {
+                    pos ligature f_i
+                            <anchor 100 500> mark @MC_top
+                        ligComponent
+                            <anchor 600 500> mark @MC_top;
+                } mark2liga;
+
+            } mark;
+
+            feature mkmk {
+                lookup mark2mark_top;
+                lookup ContextualMarkToMarkDispatch_0;
+            } mkmk;
+            """
+        )
+
     def test_contextual_anchor_no_context(self, testufo, caplog):
         a = testufo["a"]
         a.appendAnchor({"name": "*top", "x": 200, "y": 200, "identifier": "*top"})
-        a.lib[OBJECT_LIBS_KEY] = {"*top": {"foo": "bar"}}
+        a.lib[OBJECT_LIBS_KEY] = {"*top": {ANCHOR_LIB_GPOS_CONTEXT_KEY: " "}}
 
         writer = MarkFeatureWriter()
         feaFile = ast.FeatureFile()
